package com.ruoyi.web.controller.common;

import cn.hutool.core.io.IoUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.core.util.URLUtil;
import cn.hutool.http.HttpUtil;
import cn.hutool.json.JSONObject;
import com.ruoyi.common.config.RuoYiConfig;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.file.FileUtils;
import com.ruoyi.framework.config.ServerConfig;
import com.ruoyi.zhdd.feign.FeignDocumentService;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.HashMap;
import java.util.Map;

/**
 * 通用请求处理
 *
 * @author ruoyi
 */
@RestController
@Slf4j
public class CommonController {

    @Autowired
    private ServerConfig serverConfig;
    @Autowired
    private FeignDocumentService feignDocumentService;
    @Value("${third.fileUrl}")
    private String fileUrl;

    /**
     * 通用下载请求
     *
     * @param fileName 文件名称
     * @param delete 是否删除
     *//*
    @GetMapping("/common/download")
    public void fileDownload(String fileName, Boolean delete, HttpServletResponse response, HttpServletRequest request)
    {
        try
        {
            if (!FileUtils.checkAllowDownload(fileName))
            {
                throw new Exception(StringUtils.format("文件名称({})非法，不允许下载。 ", fileName));
            }
            String realFileName = System.currentTimeMillis() + fileName.substring(fileName.indexOf("_") + 1);
            String filePath = RuoYiConfig.getDownloadPath() + fileName;

            response.setContentType(MediaType.APPLICATION_OCTET_STREAM_VALUE);
            FileUtils.setAttachmentResponseHeader(response, realFileName);
            FileUtils.writeBytes(filePath, response.getOutputStream());
            if (delete)
            {
                FileUtils.deleteFile(filePath);
            }
        }
        catch (Exception e)
        {
            log.error("下载文件失败", e);
        }
    }*/

    /**
     * 通用上传请求
     */
    @SneakyThrows
    @PostMapping("/common/upload")
    public AjaxResult<?> uploadFile(MultipartFile file) {
        JSONObject jsonObject = feignDocumentService.fileUpload(file, "yjzh");
        log.info("文件上传结果：{}", jsonObject);
        if (jsonObject != null) {
            if (jsonObject.getInt("code") == 200) {
                JSONObject data = jsonObject.getJSONObject("data");
                Map<String, Object> result = new HashMap<>();
                result.put("fileName", data.getStr("realName"));
                result.put("url", URLUtil.getPath(data.getStr("url")));
                return AjaxResult.success(result);
            }
        }
        return AjaxResult.error("文件上传失败");
//        // 上传文件路径
//        String filePath = RuoYiConfig.getUploadPath();
//        // 上传并返回新文件名称
//        String fileName = FileUploadUtils.upload(filePath, file);
//        String url = serverConfig.getUrl() + fileName;
//        Map<String, Object> result = new HashMap<>();
//        result.put("fileName", fileName.substring(fileName.lastIndexOf("/") + 1));
//        result.put("url", fileName);
//        Runtime.getRuntime().exec("chmod 777 -R " + filePath);
//        return AjaxResult.success(result);
    }

    /**
     * 本地资源通用下载
     */
    @GetMapping("/common/download/resource")
    public void resourceDownload(String resource, HttpServletRequest request, HttpServletResponse response)
        throws Exception {
        try {
            if (!FileUtils.checkAllowDownload(resource)) {
                throw new Exception(StringUtils.format("资源文件({})非法，不允许下载。 ", resource));
            }
            if (StrUtil.startWith(resource, Constants.RESOURCE_PREFIX)) {
                // 本地资源路径
                String localPath = RuoYiConfig.getProfile();
                // 数据库资源地址
                String downloadPath = localPath + StringUtils.substringAfter(resource, Constants.RESOURCE_PREFIX);
                // 下载名称
                String downloadName = StringUtils.substringAfterLast(downloadPath, "/");
                response.setContentType(MediaType.APPLICATION_OCTET_STREAM_VALUE);
                FileUtils.setAttachmentResponseHeader(response, downloadName);
                FileUtils.writeBytes(downloadPath, response.getOutputStream());
            } else {
                // 网络资源
                // 下载名称
                String downloadName = StringUtils.substringAfterLast(resource, "/");
                response.setContentType(MediaType.APPLICATION_OCTET_STREAM_VALUE);
                FileUtils.setAttachmentResponseHeader(response, downloadName);
                HttpUtil.download(fileUrl + resource, response.getOutputStream(), true);
            }
        } catch (Exception e) {
            log.error("下载文件失败", e);
        }
    }

    /**
     * 下载本地资源文件
     *
     * @param resource
     * @param response
     * @throws Exception
     */
    @GetMapping("/common/download/resource/local")
    public void resourceLocalDownload(String resource, HttpServletResponse response) {
        InputStream inputStream = null;
        OutputStream outputStream = null;
        try {
            // 下载名称
            String downloadName = StringUtils.substringAfterLast(resource, "/");
            response.setContentType(MediaType.APPLICATION_OCTET_STREAM_VALUE);
            FileUtils.setAttachmentResponseHeader(response, downloadName);
//            ClassPathResource classPathResource = new ClassPathResource(resource);
            inputStream = CommonController.class.getClassLoader().getResourceAsStream(resource);
            outputStream = response.getOutputStream();

            IoUtil.copy(inputStream, outputStream);
//            FileUtils.writeBytes(resource, response.getOutputStream());
        } catch (Exception e) {
            log.error("下载文件失败", e);
        } finally {
            if (outputStream != null) {
                try {
                    outputStream.close();
                } catch (IOException e1) {
                    e1.printStackTrace();
                }
            }
            if (inputStream != null) {
                try {
                    inputStream.close();
                } catch (IOException e1) {
                    e1.printStackTrace();
                }
            }
        }
    }
}
