package com.ruoyi.web.controller.system;

import cn.hutool.core.convert.Convert;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.ArrayUtil;
import cn.hutool.core.util.StrUtil;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.annotation.Security;
import com.ruoyi.common.constant.UserConstants;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.FindsDepartsChildrenUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.service.ISysDeptService;
import com.ruoyi.zhdd.domain.GatewayDeptList;
import com.ruoyi.zhdd.feign.FeignUserManageService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 部门信息
 *
 * @author ruoyi
 */
@RestController
@RequestMapping("/system/dept")
public class SysDeptController extends BaseController {
    @Autowired
    private ISysDeptService deptService;
    @Autowired
    private FeignUserManageService feignUserManageService;

    /**
     * 获取部门列表
     */
    @GetMapping("/list")
    public AjaxResult list(SysDept dept) {
        List<SysDept> depts = deptService.selectDeptList(dept);
        return AjaxResult.success(depts);
    }

    @GetMapping("/gateway/pageList")
    public AjaxResult gatewayPageList(@RequestParam(defaultValue = "1") Integer pageNum,
                                      @RequestParam(defaultValue = "10") Integer pageSize,
                                      @RequestParam(required = false) String name) {
        return AjaxResult.success(feignUserManageService.deptPageList(pageNum, pageSize, name));
    }

    @GetMapping("/gateway/list")
    public AjaxResult gatewayList() {
        return AjaxResult.success(feignUserManageService.deptList());
    }

    @GetMapping("/gateway/detail")
    public AjaxResult gatewayList(@RequestParam String id) {
        return AjaxResult.success(feignUserManageService.deptDetail(id));
    }

    /**
     * 查询部门列表（排除节点）
     */
    @GetMapping("/list/exclude/{deptId}")
    public AjaxResult excludeChild(@PathVariable(value = "deptId", required = false) String deptId) {
        List<SysDept> depts = deptService.selectDeptList(new SysDept());
        depts.removeIf(d -> d.getDeptId().equals(deptId)
            || ArrayUtil.contains(StringUtils.split(d.getAncestors(), ","), deptId + ""));
        return AjaxResult.success(depts);
    }

    /**
     * 根据部门编号获取详细信息
     */
    @GetMapping(value = "/{deptId}")
    public AjaxResult getInfo(@PathVariable String deptId) {
//        deptService.checkDeptDataScope(deptId);
        return AjaxResult.success(deptService.selectDeptById(deptId));
    }

    /**
     * 获取部门下拉树列表
     */
    @GetMapping("/treeselect")
    public AjaxResult treeselect(SysDept dept) {
        List<SysDept> depts = deptService.selectDeptList(dept);
        return AjaxResult.success(deptService.buildDeptTreeSelect(depts));
    }

    /**
     * 加载对应角色部门列表树
     */
    @GetMapping(value = "/roleDeptTreeselect/{roleId}")
    public AjaxResult roleDeptTreeselect(@PathVariable("roleId") String roleId) {
        List<SysDept> depts = deptService.selectDeptList(new SysDept());
        Map<String, Object> ajax = new HashMap<>();
        ajax.put("checkedKeys", deptService.selectDeptListByRoleId(roleId));
        ajax.put("depts", deptService.buildDeptTreeSelect(depts));
        return AjaxResult.success(ajax);
    }

    /**
     * 新增部门
     */
    @Log(title = "部门管理", businessType = BusinessType.INSERT)
    @PostMapping
    @Security
    public AjaxResult add(@Validated @RequestBody SysDept dept) {
        if (UserConstants.NOT_UNIQUE.equals(deptService.checkDeptNameUnique(dept))) {
            return AjaxResult.error("新增部门'" + dept.getDeptName() + "'失败，部门名称已存在");
        }
        dept.setCreateBy(getUsername());
        return toAjax(deptService.insertDept(dept));
    }

    /**
     * 修改部门
     */
    @Log(title = "部门管理", businessType = BusinessType.UPDATE)
    @PutMapping
    @Security
    public AjaxResult edit(@Validated @RequestBody SysDept dept) {
        if (UserConstants.NOT_UNIQUE.equals(deptService.checkDeptNameUnique(dept))) {
            return AjaxResult.error("修改部门'" + dept.getDeptName() + "'失败，部门名称已存在");
        } else if (dept.getParentId().equals(dept.getDeptId())) {
            return AjaxResult.error("修改部门'" + dept.getDeptName() + "'失败，上级部门不能是自己");
        } else if (StringUtils.equals(UserConstants.DEPT_DISABLE, dept.getStatus())
            && deptService.selectNormalChildrenDeptById(dept.getDeptId()) > 0) {
            return AjaxResult.error("该部门包含未停用的子部门！");
        }
        dept.setUpdateBy(getUsername());
        return toAjax(deptService.updateDept(dept));
    }

    /**
     * 删除部门
     */
    @Log(title = "部门管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{deptId}")
    @Security
    public AjaxResult remove(@PathVariable String deptId) {
        if (deptService.hasChildByDeptId(deptId)) {
            return AjaxResult.error("存在下级部门,不允许删除");
        }
        if (deptService.checkDeptExistUser(deptId)) {
            return AjaxResult.error("部门存在用户,不允许删除");
        }
        return toAjax(deptService.deleteDeptById(deptId));
    }

    @PostMapping("/syncDept")
    public void syncDept() {
        GatewayDeptList list = feignUserManageService.deptList();
        List<SysDept> sysDepts = new ArrayList<>();
        for (GatewayDeptList.DeptDetail deptDetail : list.getData()) {
            SysDept sysDept = new SysDept();
            sysDept.setDeptId(deptDetail.getId());
            sysDept.setParentId(StrUtil.emptyToDefault(deptDetail.getParentId(), "0"));
            sysDept.setDeptName(deptDetail.getName());
            sysDept.setOrderNum(deptDetail.getOrdinal());
            sysDept.setCreateBy(deptDetail.getCreateUser());
            sysDept.setUpdateBy("hs");
            sysDept.setCreateTime(DateUtil.parseDateTime(deptDetail.getCreateTime()));
            sysDept.setUpdateTime(DateUtil.parseDateTime(deptDetail.getUpdateTime()));
            sysDept.setFlag(Convert.toStr(deptDetail.getFlag()));
            sysDepts.add(sysDept);
        }
        deptService.saveOrUpdateBatch(sysDepts);
        // 统一处理Ancestors、FullName
        List<SysDept> allList = deptService.list();
        // 先算第一级的
        for (SysDept dept : allList) {
            if (StrUtil.split(dept.getAncestors(), ',').size() == 1) {
                dept.setFullName(dept.getDeptName());
                deptService.updateById(dept);
            }
        }
        for (SysDept dept : allList) {
            if (StrUtil.split(dept.getAncestors(), ',').size() == 2) {
                SysDept newParentDept = deptService.getById(dept.getParentId());
                if (StringUtils.isNotNull(newParentDept)) {
                    String newAncestors = newParentDept.getAncestors() + "," + newParentDept.getDeptId();
                    dept.setAncestors(newAncestors);
                }
                String departFullNamePrefix = FindsDepartsChildrenUtil.departFullName(deptService.list(), dept.getParentId());
                dept.setFullName(StrUtil.isBlank(departFullNamePrefix) ? dept.getDeptName() : departFullNamePrefix + dept.getDeptName());
                deptService.updateById(dept);
            }
        }
        for (SysDept dept : allList) {
            if (StrUtil.split(dept.getAncestors(), ',').size() == 3) {
                SysDept newParentDept = deptService.getById(dept.getParentId());
                if (StringUtils.isNotNull(newParentDept)) {
                    String newAncestors = newParentDept.getAncestors() + "," + newParentDept.getDeptId();
                    dept.setAncestors(newAncestors);
                }
                String departFullNamePrefix = FindsDepartsChildrenUtil.departFullName(deptService.list(), dept.getParentId());
                dept.setFullName(StrUtil.isBlank(departFullNamePrefix) ? dept.getDeptName() : departFullNamePrefix + dept.getDeptName());
                deptService.updateById(dept);
            }
        }
    }

    /*@PostMapping("/syncDept")
    public void syncDept() {
        List<SysDept> list = deptService.list();
        for (SysDept dept : list) {
            if (StrUtil.isBlank(dept.getFullName())) {
                String departFullNamePrefix = FindsDepartsChildrenUtil.departFullName(list, dept.getParentId());
                dept.setFullName(StrUtil.isBlank(departFullNamePrefix) ? dept.getDeptName() : departFullNamePrefix + dept.getDeptName());
                deptService.updateById(dept);
            }
        }

    }*/

}
