package com.ruoyi.web.controller.task;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.convert.Convert;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.lang.Validator;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.crypto.SecureUtil;
import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.RedisUtils;
import com.ruoyi.system.service.ISysDeptService;
import com.ruoyi.system.service.ISysDictDataService;
import com.ruoyi.system.service.ISysUserService;
import com.ruoyi.zhdd.domain.IncidentProcess;
import com.ruoyi.zhdd.domain.IncidentUser;
import com.ruoyi.zhdd.domain.SmsOutbox;
import com.ruoyi.zhdd.domain.bo.BacklogMessagePushBo;
import com.ruoyi.zhdd.domain.bo.MessagePushBo;
import com.ruoyi.zhdd.domain.bo.MessagePushUser;
import com.ruoyi.zhdd.domain.vo.IncidentTaskVo;
import com.ruoyi.zhdd.domain.vo.IncidentVo;
import com.ruoyi.zhdd.feign.FeignBacklogInfoService;
import com.ruoyi.zhdd.feign.FeignNoticeInfoService;
import com.ruoyi.zhdd.service.IIncidentProcessService;
import com.ruoyi.zhdd.service.IIncidentService;
import com.ruoyi.zhdd.service.IIncidentTaskService;
import com.ruoyi.zhdd.service.IIncidentUserService;
import com.ruoyi.zhdd.service.ISmsOutboxService;
import com.ruoyi.zhdd.service.IThirdInterfaceService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;

/**
 * @Description: TODO
 * @Author: huangcheng
 * @Date: 2022/1/12
 * @Version V1.0
 */
@Component
@Slf4j
@RequiredArgsConstructor(onConstructor_ = @Autowired)
public class NoticeInfoListiner {

    private final FeignNoticeInfoService feignNoticeInfoService;
    private final FeignBacklogInfoService feignBacklogInfoService;
    private final IIncidentService incidentService;
    private final IIncidentTaskService incidentTaskService;
    private final IIncidentProcessService incidentProcessService;
    private final ISmsOutboxService smsOutboxService;
    private final ISysUserService sysUserService;
    private final IIncidentUserService incidentUserService;
    private final ISysDictDataService dictDataService;
    private final ISysDeptService sysDeptService;
    private final IThirdInterfaceService thirdInterfaceService;

    @Value("${spring.profiles.active}")
    private String env;

    @Value("${third.incidentUrl}")
    private String incidentUrl;
    @Value("${third.incidentDetailUrl}")
    private String incidentDetailUrl;
    @Value("${third.resourceUrl}")
    private String resourceUrl;

    /**
     * 消息发送
     * A:事件派发。B:处置方案
     */
    @Bean
    public void sendNotice() {
        RedisUtils.subscribe(Constants.NOTICE_PUSH, String.class, msg -> {
            try {
                TimeUnit.MILLISECONDS.sleep(1000);
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
            log.info("订阅事件消息 => {}", msg);
            // 查询事件信息并发送消息
            MessagePushBo messagePushBo = new MessagePushBo();
            // (1-应急处置消息、2-应急处置待办、3-资源管理待办、4-事件派发普通消息)
            String messageType = msg.substring(0, 1);
            String type = msg.substring(1, 2);
            String title = "未知";
            String synopsis = "未知";
            String msText = "";
            String content = "";
            String messageUser = "";
            String incidentId;
            String url = "";
            IncidentProcess incidentProcess = new IncidentProcess();
            boolean sendFlag = true;

            if ("1".equals(messageType)) {
                incidentProcess.setStatus(1);
            } else if ("2".equals(messageType) || "3".equals(messageType)) {
                incidentProcess.setStatus(2);
            }
            if ("A".equals(type)) {
                IncidentVo incidentVo = incidentService.queryById(msg.substring(2));
                title = StrUtil.concat(true, incidentVo.getName());
                synopsis = "请查看派发应急事件消息";
                content = getDetail(incidentVo).toString();
                // 组装主办单位人员数据
                String madinTaskUser = incidentVo.getMadinTaskUser();
                String madinUserText = "";
                if (StrUtil.isNotBlank(madinTaskUser)) {
                    List<MessagePushUser> messagePushUsers = JSONUtil.toList(madinTaskUser, MessagePushUser.class);
                    madinUserText = messagePushUsers.stream().map(MessagePushUser::getNickName).collect(Collectors.joining(","));
                }
                incidentProcess.setDes(StrUtil.concat(true, "派发给", incidentVo.getMadinDeptText(), "主办单位的", madinUserText, "。"));
                incidentProcess.setIncidentStatus(2);
                incidentProcess.setIncidentId(msg.substring(2));
                messageUser = JSONUtil.toJsonStr(CollUtil.unionDistinct(JSONUtil.toList(incidentVo.getMadinTaskUser(), MessagePushUser.class),
                    JSONUtil.toList(StrUtil.blankToDefault(incidentVo.getMadinDeptUser(), "[]"), MessagePushUser.class)));
            } else if ("B".equals(type)) {
                // 查询处置方案
                IncidentTaskVo incidentTaskVo = incidentTaskService.queryById(msg.substring(2));
                log.info("查询的处置指令：{}", incidentTaskVo);
                incidentId = incidentTaskVo.getIncidentId();
                IncidentVo incidentVo = incidentService.queryById(incidentTaskVo.getIncidentId());
                title = StrUtil.concat(true, incidentVo.getName());
                synopsis = incidentTaskVo.getTaskName();
                content = getDetail(incidentVo).toString();

                url = incidentUrl.replace("#incidentId", incidentId).replace("#taskId", incidentTaskVo.getId());
                incidentProcess.setDes("发送处置指令");
                incidentProcess.setIncidentStatus(3);
                incidentProcess.setIncidentId(incidentTaskVo.getIncidentId());
                messageUser = incidentTaskVo.getExprJson();
                if ("3".equals(messageType)) {
                    title = "应急资源维护";
                    msText = incidentTaskVo.getTaskName();
                    url = resourceUrl.replace("#taskId", incidentTaskVo.getId());
                } else if ("2".equals(messageType)) {
                    msText = incidentTaskVo.getTaskName();
                }
                incidentProcess.setTaskId(incidentTaskVo.getId());
            }
            if (StrUtil.isBlank(messageUser)) {
                sendFlag = false;
                log.info("无发送人员");
                incidentProcess.setDes("新增处置指令");
                // 发送的标识，用于是否去查询已读未读人员的
                incidentProcess.setStatus(0);
            }
            List<MessagePushUser> messagePushUsers = JSONUtil.toList(messageUser, MessagePushUser.class);
            // 针对待办的消息，执行日志还需要把人名显示出来
            if (2 == incidentProcess.getStatus()) {
                incidentProcess.setDes(incidentProcess.getDes() + " 到" + messagePushUsers.stream().map(MessagePushUser::getNickName).collect(Collectors.joining(",")) + "。【待办】");
            }
            incidentProcessService.save(incidentProcess);
            if (sendFlag) {
                if ("1".equals(messageType)) {
                    // 普通消息
                    messagePushBo.setTitle(title);
                    messagePushBo.setMsSynopsis(synopsis);
                    messagePushBo.setContent(content);
//                    messagePushBo.setSenderId();
                    messagePushBo.setUrl(incidentDetailUrl.replace("#incidentId", incidentProcess.getIncidentId()));
                    messagePushBo.setUuId(incidentProcess.getId());
                    messagePushBo.setMessageReadInfoList(messagePushUsers);
                    messagePushBo.setVerify(SecureUtil.md5(StrUtil.concat(true, messagePushBo.getAppId(), messagePushBo.getSendTime(), messagePushBo.getContent())));
                    log.info("发送普通消息 => {}", messagePushBo);
                    if (!"dev".equals(env)) {
                        JSONObject jsonObject = feignNoticeInfoService.messagePush(messagePushBo);
                        log.info("发送普通消息结果：{}", jsonObject);
                    }
                } else if ("2".equals(messageType) || "3".equals(messageType)) {
                    // 应急处置待办
                    BacklogMessagePushBo backlogMessagePushBo = new BacklogMessagePushBo();
                    backlogMessagePushBo.setUuId(incidentProcess.getId());
                    backlogMessagePushBo.setTitle(title);
                    backlogMessagePushBo.setContent(msText);
                    backlogMessagePushBo.setVerify(SecureUtil.md5(StrUtil.concat(true, backlogMessagePushBo.getAppId(), backlogMessagePushBo.getSendTime(), backlogMessagePushBo.getContent())));
                    backlogMessagePushBo.setUrl(url);
                    List<String> userIds = messagePushUsers.stream().map(MessagePushUser::getUserId).collect(Collectors.toList());
                    backlogMessagePushBo.setReceiverId(userIds);
                    log.info("待办消息发送 => {}", backlogMessagePushBo);
                    if (!"dev".equals(env)) {
                        Object o = feignBacklogInfoService.backlogMessagePush(backlogMessagePushBo);
                        log.info("发送待办消息结果：{}", o);
                    }

                    // 查询发送用户的手机号(由于消息接口有发送了短信，则只在待办消息时发短信)
                    List<String> collect = messagePushUsers.stream().map(MessagePushUser::getUserId).collect(Collectors.toList());
                    List<SysUser> list = sysUserService.list(Wrappers.<SysUser>lambdaQuery().in(SysUser::getUserId, collect));
                    // 组装短信内容
                    List<SmsOutbox> smsOutboxes = new ArrayList<>();
                    for (SysUser sysUser : list) {
                        if (StrUtil.isNotBlank(sysUser.getPhonenumber()) && Validator.isMobile(sysUser.getPhonenumber())) {
                            SmsOutbox smsOutbox = new SmsOutbox();
                            smsOutbox.setDestaddr(sysUser.getPhonenumber());
                            smsOutbox.setMessagecontent("有新的应急事件或应急方案，请登录APP注意查看！");
                            smsOutbox.setRequesttime(new Date());
                            smsOutboxes.add(smsOutbox);
                        }
                    }
                    if (!"dev".equals(env)) {
                        smsOutboxService.saveBatch(smsOutboxes);
                        log.debug("发送短信 => {}", smsOutboxes);
                    }
                }

            }
        });
    }

    /**
     * 获取事件详情
     *
     * @param incidentVo
     * @return
     */
    private JSONArray getDetail(IncidentVo incidentVo) {
        // 翻译事件类型、事件等级、事件来源、上报人员、上报单位
        String type = "";
        String level = "";
        String source = "";
        if (ObjectUtil.isNotEmpty(incidentVo.getType())) {
            type = dictDataService.selectDictLabel("zhdd_incident_type", Convert.toStr(incidentVo.getType()));
        }
        if (ObjectUtil.isNotEmpty(incidentVo.getLevel())) {
            level = dictDataService.selectDictLabel("zhdd_incident_level", Convert.toStr(incidentVo.getLevel()));
        }
        if (StrUtil.isNotBlank(incidentVo.getSource())) {
            source = dictDataService.selectDictLabel("zhdd_incident_source", incidentVo.getSource());
        }
        incidentVo.setTypeText(type);
        incidentVo.setLevelText(level);
        incidentVo.setSource(source);
        SysUser sysUser = sysUserService.selectUserByUserName(incidentVo.getCreateBy());
        if (sysUser != null) {
            incidentVo.setCreateBy(sysUser.getNickName());
        }
        SysDept sysDept = sysDeptService.selectDeptById(incidentVo.getCreateDept());
        if (sysDept != null) {
            incidentVo.setCreateDept(sysDept.getDeptName());
        }
        JSONArray array = new JSONArray();
        JSONObject time = new JSONObject();
//        jsonObject.set("key", "事件类型");
//        jsonObject.set("val", incidentVo.getTypeText());
//        array.add(jsonObject);
//        jsonObject.set("key", "事件等级");
//        jsonObject.set("val", incidentVo.getLevelText());
//        array.add(jsonObject);
        time.set("key", "事件时间");
        time.set("val", DateUtil.formatDateTime(incidentVo.getCreateTime()));
        array.add(time);
        JSONObject address = new JSONObject();
        address.set("key", "事件地点");
        address.set("val", incidentVo.getAddr());
        array.add(address);
        JSONObject incSource = new JSONObject();
        incSource.set("key", "事件来源");
        incSource.set("val", incidentVo.getSource());
        array.add(incSource);
        JSONObject userName = new JSONObject();
        userName.set("key", "上报人员");
        userName.set("val", incidentVo.getCreateBy());
        array.add(userName);
//        jsonObject.set("key", "联系电话");
//        jsonObject.set("val", incidentVo.getExpr1());
//        array.add(jsonObject);
//        jsonObject.set("key", "上报单位");
//        jsonObject.set("val", incidentVo.getCreateDept());
//        array.add(jsonObject);

        return array;
    }

    /**
     * 指定用户发送
     */
    @Bean
    public void sendNoticeSingle() {
        RedisUtils.subscribe(Constants.NOTICE_PUSH_SINGLE, JSONObject.class, msg -> {
            try {
                TimeUnit.MILLISECONDS.sleep(2000);
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
            log.info("发送指定用户订阅事件消息 => {}", msg);
            String des = msg.getStr("des");
            String taskId = msg.getStr("taskId");
            int incidentStatus = msg.getInt("incidentStatus");
            String incidentId = msg.getStr("incidentId");
            List<MessagePushUser> messagePushUsers = JSONUtil.toList(msg.getStr("messagePushUsers"), MessagePushUser.class);

            // 查询事件信息并发送消息
            MessagePushBo messagePushBo = new MessagePushBo();
            String title;
            String synopsis;
            String text;

            IncidentProcess incidentProcess = new IncidentProcess();
            incidentProcess.setDes(des);
            incidentProcess.setIncidentStatus(incidentStatus);
            incidentProcess.setStatus(1);
            incidentProcess.setIncidentId(incidentId);
            incidentProcess.setTaskId(taskId);
            incidentProcessService.save(incidentProcess);

            IncidentVo incidentVo = incidentService.queryById(incidentId);
            title = StrUtil.concat(true, incidentVo.getName());
            synopsis = "系统给您派发了应急事件，请查看";
//            text = StrUtil.concat(true, incidentVo.getAddr(), "发生应急事件，请关注消息，做好应急准备");
            text = getDetail(incidentVo).toString();

            // 普通消息
            messagePushBo.setTitle(title);
            messagePushBo.setMsSynopsis(synopsis);
            messagePushBo.setContent(text);
            messagePushBo.setUrl(incidentDetailUrl.replace("#incidentId", incidentProcess.getIncidentId()));
            messagePushBo.setUuId(incidentProcess.getId());
            messagePushBo.setMessageReadInfoList(messagePushUsers);
            messagePushBo.setVerify(SecureUtil.md5(StrUtil.concat(true, messagePushBo.getAppId(), messagePushBo.getSendTime(), messagePushBo.getContent())));
//            messagePushBo.setContent(content);
//            messagePushBo.setSenderId();

            log.info("发送普通消息 => {}", messagePushBo);
            if (!"dev".equals(env)) {
                JSONObject jsonObject = feignNoticeInfoService.messagePush(messagePushBo);
                log.info("发送普通消息结果：{}", jsonObject);
            }

            /*// 查询发送用户的手机号
            List<String> collect = messagePushUsers.stream().map(MessagePushUser::getUserId).collect(Collectors.toList());
            List<SysUser> list = sysUserService.list(Wrappers.<SysUser>lambdaQuery().in(SysUser::getUserId, collect));
            // 组装短信内容
            List<SmsOutbox> smsOutboxes = new ArrayList<>();
            for (SysUser sysUser : list) {
                if (StrUtil.isNotBlank(sysUser.getPhonenumber()) && Validator.isMobile(sysUser.getPhonenumber())) {
                    SmsOutbox smsOutbox = new SmsOutbox();
                    smsOutbox.setDestaddr(sysUser.getPhonenumber());
                    smsOutbox.setMessagecontent("有新的应急事件或应急方案，请登录APP注意查看！");
                    smsOutbox.setRequesttime(new Date());
                    smsOutboxes.add(smsOutbox);
                }
            }
            if (!"dev".equals(env)) {
                smsOutboxService.saveBatch(smsOutboxes);
                log.debug("发送短信 => {}", smsOutboxes);
            }*/
        });
    }

    @Bean
    public void processRecord() {
        RedisUtils.subscribe(Constants.PROCESS_RECORD, JSONObject.class, msg -> {
            // 记录处置详情
            String incidentId = msg.getStr("incidentId");
            Integer incidentStatus = msg.getInt("incidentStatus");
            String taskId = msg.getStr("taskId");
            String des = msg.getStr("des");
            IncidentProcess incidentProcess = new IncidentProcess();
            if (StrUtil.isBlank(des)) {
                if (incidentStatus == 2) {
                    des = "事件续报";
                } else if (incidentStatus == 4) {
                    des = "事件归档";
                } else if (incidentStatus == 5) {
                    des = "事件忽略";
                } else if (incidentStatus == 6) {
                    des = "事件办结";
                } else {
                    des = "未知";
                }
            }
            incidentProcess.setDes(des);
            incidentProcess.setIncidentStatus(incidentStatus);
            incidentProcess.setIncidentId(incidentId);
            incidentProcess.setTaskId(taskId);
            incidentProcess.setStatus(0);
            log.info("保存事件处置执行日志：{}", incidentProcess);
            incidentProcessService.save(incidentProcess);
        });
    }

    /**
     * 批量新增用户和事件的关系
     */
    @Bean
    public void saveBatchIncidentUser() {
        RedisUtils.subscribe(Constants.INCIDENT_USER_BATCH, JSONArray.class, msg -> {
            log.info("批量保存事件人员关系 => " + msg);
            List<IncidentUser> incidentUsers = JSONUtil.toList(msg, IncidentUser.class);
            incidentUserService.saveAll(incidentUsers);
        });
    }

    /**
     * 删除用户和事件的关系
     */
    @Bean
    public void removeIncidentUser() {
        RedisUtils.subscribe(Constants.INCIDENT_USER_DELETE, JSONArray.class, msg -> {
            log.info("移除事件人员关系 => " + msg);
            List<IncidentUser> incidentUsers = JSONUtil.toList(msg, IncidentUser.class);
            for (IncidentUser incidentUser : incidentUsers) {
                incidentUserService.remove(Wrappers.<IncidentUser>lambdaQuery()
                    .eq(IncidentUser::getUserId, incidentUser.getUserId())
                    .eq(IncidentUser::getIncidentId, incidentUser.getIncidentId())
                    .eq(IncidentUser::getSource, incidentUser.getSource()));
            }
        });
    }

    /**
     * APP信息更新
     */
    @Bean
    public void appUpdate() {
        RedisUtils.subscribe(Constants.UPDATE_APP_PUSH, String.class, thirdInterfaceService::updateAppInfo);
    }

}
