package com.ruoyi.web.controller.task;

import cn.hutool.core.util.NumberUtil;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.utils.RedisUtils;
import com.ruoyi.zhdd.service.*;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.Map;

/**
 * @Description: TODO
 * @Author: huangcheng
 * @Date: 2022/7/5
 * @Version V1.0
 */
@Component
@EnableScheduling   // 1.开启定时任务
@EnableAsync        // 2.开启多线程
@Slf4j
@RequiredArgsConstructor(onConstructor_ = @Autowired)
public class ScheduleTask {

    private final IChemicalDataService chemicalDataService;
    private final IDutyReportService dutyReportService;
    private final IDutyReportRecordService dutyReportRecordService;
    private final IIncidentService incidentService;
    private final IIncidentProcessService incidentProcessService;
    private final IIncidentTaskService incidentTaskService;
    private final IPlanService planService;
    private final IResourceService resourceService;
    private final IResourceDetailService resourceDetailService;
    private final IDhService dhService;


    @Async
    @Scheduled(cron = "0 0 0/1 * * ?")
    public void countTable() {
        log.info("开始计算表数据量");
        long count = chemicalDataService.count();
        long count1 = dutyReportService.count();
        long count2 = dutyReportRecordService.count();
        long count3 = incidentService.count();
        long count4 = incidentProcessService.count();
        long count5 = incidentTaskService.count();
        long count6 = planService.count();
        long count7 = resourceService.count();
        long count8 = resourceDetailService.count();
        BigDecimal add = NumberUtil.add(count, count1, count2, count3, count4, count5, count6, count7, count8);
        RedisUtils.setCacheObject(Constants.DATA_TOTAL_COUNT, add);
    }

    /**
     * 对大华token保活
     */
    @Async
    @Scheduled(cron = "0/10 * * * * ?")
    public void keepliveDhToken() {
        boolean pcToken = RedisUtils.exist(Constants.CACHE_DH_VIDEO_TOKEN);
        boolean hdToken = RedisUtils.exist(Constants.CACHE_DH_VIDEO_HD_TOKEN);
        boolean testToken = RedisUtils.exist(Constants.CACHE_DH_TOKEN);
        boolean fuyongToken = RedisUtils.exist(Constants.CACHE_DH_FUYONG_TOKEN);
        if (pcToken) {
            long ttl = RedisUtils.getTtl(Constants.CACHE_DH_VIDEO_TOKEN);
            if (NumberUtil.compare(ttl, 0) == 1 && NumberUtil.compare(ttl, 30000) == -1) {
                // 保活token
                Map<String, String> token = RedisUtils.getCacheMap(Constants.CACHE_DH_VIDEO_TOKEN);
                dhService.tokenKeepalive(token.get("token"), 120, Constants.CACHE_DH_VIDEO_TOKEN);
                log.info("大华token已保活：key={}.token={}", Constants.CACHE_DH_VIDEO_TOKEN, token.get("token"));
            }
        }
        if (hdToken) {
            long ttl = RedisUtils.getTtl(Constants.CACHE_DH_VIDEO_HD_TOKEN);
            if (NumberUtil.compare(ttl, 0) == 1 && NumberUtil.compare(ttl, 30000) == -1) {
                // 保活token
                Map<String, String> token = RedisUtils.getCacheMap(Constants.CACHE_DH_VIDEO_HD_TOKEN);
                dhService.tokenKeepalive(token.get("token"), 120, Constants.CACHE_DH_VIDEO_HD_TOKEN);
                log.info("大华token已保活：key={}.token={}", Constants.CACHE_DH_VIDEO_HD_TOKEN, token.get("token"));
            }
        }
        if (testToken) {
            long ttl = RedisUtils.getTtl(Constants.CACHE_DH_TOKEN);
            if (NumberUtil.compare(ttl, 0) == 1 && NumberUtil.compare(ttl, 30000) == -1) {
                // 保活token
                Map<String, String> token = RedisUtils.getCacheMap(Constants.CACHE_DH_TOKEN);
                dhService.tokenKeepalive(token.get("token"), 120, Constants.CACHE_DH_TOKEN);
                log.info("大华token已保活：key={}.token={}", Constants.CACHE_DH_TOKEN, token.get("token"));
            }
        }
        if (fuyongToken) {
            long ttl = RedisUtils.getTtl(Constants.CACHE_DH_FUYONG_TOKEN);
            if (NumberUtil.compare(ttl, 0) == 1 && NumberUtil.compare(ttl, 30000) == -1) {
                // 保活token
                Map<String, String> token = RedisUtils.getCacheMap(Constants.CACHE_DH_FUYONG_TOKEN);
                dhService.tokenKeepalive(token.get("token"), 120, Constants.CACHE_DH_FUYONG_TOKEN);
                log.info("大华token已保活：key={}.token={}", Constants.CACHE_DH_FUYONG_TOKEN, token.get("token"));
            }
        }
    }
}
