package com.ruoyi.web.controller.task;

import cn.hutool.core.convert.Convert;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.FindsDepartsChildrenUtil;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.service.ISysDeptService;
import com.ruoyi.system.service.ISysDictTypeService;
import com.ruoyi.system.service.ISysUserService;
import com.ruoyi.zhdd.domain.GatewayDeptList;
import com.ruoyi.zhdd.domain.GatewayUserDetail;
import com.ruoyi.zhdd.domain.GatewayUserPage;
import com.ruoyi.zhdd.domain.Resource;
import com.ruoyi.zhdd.domain.SingleDevice;
import com.ruoyi.zhdd.domain.bo.ResourceBo;
import com.ruoyi.zhdd.domain.bo.SingleDeviceBo;
import com.ruoyi.zhdd.feign.FeignUserManageService;
import com.ruoyi.zhdd.service.IResourceService;
import com.ruoyi.zhdd.service.ISingleDeviceService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.kafka.annotation.KafkaListener;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;

@Component
@Slf4j
public class SysGatewayUserTask {

    @Autowired
    ISysUserService userService;

    @Autowired
    ISysDeptService deptService;

    @Autowired
    private ISingleDeviceService singleDeviceService;

    @Autowired
    private FeignUserManageService feignUserManageService;

    @Autowired
    private IResourceService resourceService;

    @Autowired
    private ISysDictTypeService sysDictTypeService;

//    @Autowired
//    private WebSocketServer webSocketServer;

    /**
     * kfka用户同步
     *
     * @param message
     */
    @KafkaListener(topics = "t_uc_user")
    public void onUserMessage(String message) {
        log.info("kafka用户信息消费：{}", message);
        try {
            GatewayUserPage.UserDetail userPage = JSONUtil.toBean(message, GatewayUserPage.UserDetail.class);
            if ("2".equals(userPage.getDelFlag())) {
                // 代表删除
                userService.deleteUserById(userPage.getUserId());
                return;
            }
            // 查询四维用户详情
            GatewayUserDetail userDetail = feignUserManageService.userDetail(userPage.getUserId());
            if (userDetail != null) {
                log.info("四维用户详情：{}", userDetail);
                GatewayUserDetail.UserDetail data = userDetail.getData();
                SysUser newUser = new SysUser();
                // 如果是企业用户，则查询是否存在企业信息，存在则新增企业部门，同时往应急仓库新增一个数据
                if (data.getUserGroupId() == 4) {
                    GatewayUserDetail.EntInfo entInfo = data.getEntInfo();
                    if (entInfo != null && StrUtil.isAllNotBlank(entInfo.getEntName(), entInfo.getOwnerId(), entInfo.getOwnerCategory())) {
                        newUser.setDeptId(entInfo.getOwnerId());
                        newUser.setOrgId(entInfo.getOwnerId());
                        SysDept sysDept = deptService.selectDeptById(entInfo.getOwnerId());
                        String locationType = "2";
                        if (sysDept == null) {
                            sysDept = new SysDept();
                            sysDept.setDeptId(entInfo.getOwnerId());
                            sysDept.setDeptName(entInfo.getEntName());
                            sysDept.setFlag("0");
                            // 根据企业类型放置不同的目录中
                            if ("危货业户".equals(entInfo.getOwnerCategory())) {
                                sysDept.setParentId("10001");
                            } else if ("普货业户".equals(entInfo.getOwnerCategory())) {
                                sysDept.setParentId("10002");
                            } else if ("客运业户".equals(entInfo.getOwnerCategory())) {
                                sysDept.setParentId("10003");
                            } else if ("出租车业户".equals(entInfo.getOwnerCategory())) {
                                sysDept.setParentId("10004");
                            } else if ("公交运输业户".equals(entInfo.getOwnerCategory())) {
                                sysDept.setParentId("10005");
                            } else if ("汽车租赁业户".equals(entInfo.getOwnerCategory())) {
                                sysDept.setParentId("10006");
                            } else if ("检测站业户".equals(entInfo.getOwnerCategory())) {
                                sysDept.setParentId("10007");
                            } else if ("网约车平台".equals(entInfo.getOwnerCategory())) {
                                sysDept.setParentId("10008");
                            } else if ("维修站".equals(entInfo.getOwnerCategory())) {
                                sysDept.setParentId("10009");
                            } else if ("其他".equals(entInfo.getOwnerCategory())) {
                                sysDept.setParentId("10010");
                            } else if ("公路工程".equals(entInfo.getOwnerCategory())) {
                                sysDept.setParentId("10011");
                            } else if ("水运工程".equals(entInfo.getOwnerCategory())) {
                                sysDept.setParentId("10012");
                                locationType = "1";
                            } else if ("航运企业".equals(entInfo.getOwnerCategory())) {
                                sysDept.setParentId("10013");
                                locationType = "1";
                            } else if ("港口码头".equals(entInfo.getOwnerCategory())) {
                                sysDept.setParentId("10014");
                                locationType = "1";
                            } else if ("水上游览经营".equals(entInfo.getOwnerCategory())) {
                                sysDept.setParentId("10015");
                                locationType = "1";
                            } else if ("货运场站".equals(entInfo.getOwnerCategory())) {
                                sysDept.setParentId("10016");
                            }
                            deptService.insertDept(sysDept);
                        }
                        List<Resource> resourcesList = resourceService.list(Wrappers.<Resource>lambdaQuery().eq(Resource::getManageUnitId, entInfo.getOwnerId()));
                        if (resourcesList == null || resourcesList.size() == 0) {
                            // 新增应急仓库
                            ResourceBo resource = new ResourceBo();
                            resource.setAdminOrgName(entInfo.getAdminOrgName());
                            resource.setResourceType(1);
                            resource.setName(entInfo.getEntName() + "仓库");
                            resource.setManageUnit(entInfo.getEntName());
                            resource.setContactName(data.getName());
                            resource.setContactPhone(data.getMobile());
                            resource.setLocationType(locationType);
                            resource.setManageUnitId(entInfo.getOwnerId());
                            // 默认为宿迁市交通局坐标
                            resource.setLatitude("33.961569");
                            resource.setLongitude("118.260139");
                            resourceService.insertByBo(resource);
                        }
                    }
                }
                newUser.setUserId(data.getUserId());
                if (data.getPosts() != null && data.getPosts().size() > 0) {
                    newUser.setDeptId(data.getPosts().get(0).getDeptId());
                    // 查询deptId对应的orgId
                    if (StrUtil.isNotBlank(newUser.getDeptId())) {
                        SysDept sysDept = deptService.selectDeptById(newUser.getDeptId());
                        SysDept orgDept = deptService.getOrgDept(sysDept);
                        if (orgDept != null) {
                            newUser.setOrgId(orgDept.getDeptId());
                        }
                    }
                }
                newUser.setUserName(data.getUserName());
                newUser.setNickName(data.getName());
                newUser.setUserType(Convert.toStr(data.getUserGroupId()));
                newUser.setPhonenumber(StrUtil.cleanBlank(data.getMobile()));
                newUser.setPassword(SecurityUtils.encryptPassword("tocc!suqian"));
                newUser.setSex(data.getSex());
                newUser.setStatus(data.getStatus());
                newUser.setDelFlag("0");
                newUser.setUpdateBy("hs");
                newUser.setUpdateTime(new Date());
                newUser.setCreateBy("gateway");
                newUser.setCreateTime(new Date());
                userService.insertUser(newUser);
            }
        } catch (Exception e) {
            log.error("t_uc_use的kafka消费异常：{}", e.getMessage());
        }
    }

    /**
     * 四维组织部门数据消费
     * '{"id":"6913667dddd34c5ab8894164fb58d296","name":"华设测试","parentId":"310c4af66f1a4f9586bfee9c432e1ab2","parentName":"沭阳县交通运输局","flag":0,"createTime":"2022-09-14 11:20:07","createUser":"sqadmin1","updateTime":"2022-09-14 11:53:07","updateUser":"sqadmin1","delFlag":"0","fullName":null,"ordinal":null}'
     *
     * @param message
     */
    @KafkaListener(topics = "t_uc_orgdept")
    public void onDeptMessage(String message) {
        log.info("kafka部门信息消费：{}", message);
        try {
            GatewayDeptList.DeptDetail gatewayDept = JSONUtil.toBean(message, GatewayDeptList.DeptDetail.class);
            if (gatewayDept != null) {
                if ("2".equals(gatewayDept.getDelFlag())) {
                    // 2为删除部门
                    deptService.removeById(gatewayDept.getId());
                    return;
                }
                SysDept qdept = new SysDept();
                qdept.setDeptId(gatewayDept.getId());
                qdept.setParentId(StrUtil.emptyToDefault(gatewayDept.getParentId(), "0"));
                qdept.setDeptName(gatewayDept.getName());
                qdept.setOrderNum(gatewayDept.getOrdinal());
                qdept.setUpdateBy(gatewayDept.getUpdateUser());
                qdept.setUpdateTime(DateUtil.parseDateTime(gatewayDept.getUpdateTime()));
                qdept.setCreateBy(gatewayDept.getCreateUser());
                qdept.setCreateTime(DateUtil.parseDateTime(gatewayDept.getCreateTime()));
                qdept.setDelFlag(gatewayDept.getDelFlag());
                qdept.setFlag(Convert.toStr(gatewayDept.getFlag()));

                SysDept info = deptService.getById(qdept.getParentId());
                if (info != null) {
                    qdept.setAncestors(info.getAncestors() + "," + qdept.getParentId());
                } else {
                    // 找不到父类
                    // 情况1：有父类，但是之前的部门缺失了
//                    deptService.dealMissDept(qdept.getParentId());
                }
                String departFullNamePrefix = FindsDepartsChildrenUtil.departFullName(deptService.list(), qdept.getParentId());
                qdept.setFullName(StrUtil.isBlank(departFullNamePrefix) ? qdept.getDeptName() : departFullNamePrefix + qdept.getDeptName());
                deptService.saveOrUpdate(qdept);
            }
        } catch (Exception e) {
            log.error("t_uc_orgdept的kafka消费异常：{}", e.getMessage());
        }
    }

    /**
     * 单兵实时位置消费
     *
     * @param message
     */
    @KafkaListener(topics = "gps_executestation_581a2b5cb28e429bb56a3c6b8cbdf5a6")
    public void onDeviceMessage(String message) {
        log.info("kafka单兵设备信息消费：{}", message);
        JSONObject jsonObject = JSONUtil.parseObj(message);
        JSONObject info = jsonObject.getJSONObject("info");
        if (info != null) {
            JSONArray gps = info.getJSONArray("gps");
            if (gps != null && !gps.isEmpty()) {
                for (Object gp : gps) {
                    SingleDeviceBo singleDeviceBo = JSONUtil.toBean(Convert.toStr(gp), SingleDeviceBo.class);
                    // 根据deviceCod删除再新增
                    singleDeviceService.remove(Wrappers.<SingleDevice>lambdaQuery().eq(SingleDevice::getDeviceCode, singleDeviceBo.getDeviceCode()));
                    String utcTime = singleDeviceBo.getTime();
                    if (StrUtil.isNotBlank(utcTime)) {
                        String concat = StrUtil.concat(true, utcTime.substring(0, 4), "-", utcTime.substring(4, 6), "-", utcTime.substring(6, 11), ":", utcTime.substring(11, 13), ":", utcTime.substring(13));
                        singleDeviceBo.setTime(DateUtil.formatDateTime(DateUtil.parseUTC(concat)));
                    }
                    singleDeviceService.insertByBo(singleDeviceBo);
                }
            }
        }
    }

    /**
     * 语音指令
     *
     * @param message
     */
//    @KafkaListener(topics = "voice-vcg")
//    public void onVoiceMessage(String message) {
//        log.info("kafka语音指令消费：{}", message);
//        JSONObject jsonObject = JSONUtil.parseObj(message);
//        String id = jsonObject.getStr("id");
//        String wordValue = jsonObject.getStr("wordValue");
//        List<SysDictData> zhdd_voice = sysDictTypeService.selectDictDataByType("zhdd_voice");
//        for (SysDictData sysDictData : zhdd_voice) {
//            if (sysDictData.getDictLabel().contains(wordValue)) {
//                JSONObject obj = new JSONObject();
//                obj.set(WebsocketConst.MSG_CMD, sysDictData.getDictValue());
//                obj.set(WebsocketConst.MSG_ID, id);
//                obj.set(WebsocketConst.MSG_TXT, wordValue);
//                webSocketServer.sendAllMessage(obj.toString());
//                break;
//            }
//        }
//    }

}
