package com.ruoyi.web.controller.zhdd;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Security;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.UserUtil;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.zhdd.domain.DutyReport;
import com.ruoyi.zhdd.domain.DutyReportRecord;
import com.ruoyi.zhdd.domain.bo.DutyReportBo;
import com.ruoyi.zhdd.domain.vo.DutyReportRecordVo;
import com.ruoyi.zhdd.domain.vo.DutyReportVo;
import com.ruoyi.zhdd.service.IDutyReportRecordService;
import com.ruoyi.zhdd.service.IDutyReportService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Set;

/**
 * 值班报告信息Controller
 *
 * @author xintong
 * @date 2021-10-11
 */
@Validated
@Api(value = "值班报告信息控制器", tags = {"值班报告信息管理"})
@RequiredArgsConstructor(onConstructor_ = @Autowired)
@RestController
@RequestMapping("/zhdd/dutyReport")
public class DutyReportController extends BaseController {

    private final IDutyReportService iDutyReportService;
    private final IDutyReportRecordService dutyReportRecordService;

    @ApiOperation("查询值班报告信息列表")
    @GetMapping("/list")
    @Security
    public TableDataInfo<DutyReportVo> list(@Validated(QueryGroup.class) DutyReportBo bo) {
        // 根据当前用户的角色
        LoginUser cacheLoginUser = UserUtil.getCacheLoginUser();
        // 查询角色如果包含admin的，直接查询全部
        Set<String> userRole = cacheLoginUser.getUserRole();
        boolean admin = CollUtil.containsAny(userRole, CollUtil.newHashSet("admin"));
        if (!admin) {
            bo.setCreateBy(cacheLoginUser.getUsername());
        }
        return iDutyReportService.queryPageList(bo);
    }

    @ApiOperation("查询当前登录人员是否有未交班的报告")
    @GetMapping("/queryUnSubmitReport")
    @Security
    public AjaxResult queryUnSubmitReport() {
        LoginUser cacheLoginUser = UserUtil.getCacheLoginUser();
        return AjaxResult.success(iDutyReportService.getVoOne(Wrappers.<DutyReport>lambdaQuery()
            .eq(DutyReport::getCreateBy, cacheLoginUser.getUsername())
            .eq(DutyReport::getStatus, 1)));
    }

    @ApiOperation("查询当前登录人员是否有需要接班的报告")
    @GetMapping("/queryreceiveReport")
    @Security
    public AjaxResult queryreceiveReport() {
        // 先更新掉已过期的
        dutyReportRecordService.update(Wrappers.<DutyReportRecord>lambdaUpdate()
            .eq(DutyReportRecord::getStatus, 2)
            .le(DutyReportRecord::getDeadline, new Date())
            .set(DutyReportRecord::getStatus, 4));
        iDutyReportService.update(Wrappers.<DutyReport>lambdaUpdate()
            .eq(DutyReport::getStatus, 2)
            .le(DutyReport::getDeadline, new Date())
            .set(DutyReport::getStatus, 4));

        LoginUser cacheLoginUser = UserUtil.getCacheLoginUser();
        List<DutyReportRecordVo> dutyReportRecordVos = dutyReportRecordService.listVo(Wrappers.<DutyReportRecord>lambdaQuery()
            .eq(DutyReportRecord::getReceiveUser, cacheLoginUser.getUsername())
            .eq(DutyReportRecord::getStatus, 2)
            .ge(DutyReportRecord::getDeadline, new Date()));
        return AjaxResult.success(dutyReportRecordVos);
    }

    /**
     * 导出值班报告信息列表
     */
    @ApiOperation("导出值班报告信息列表")
    @Log(title = "值班报告信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public void export(@Validated DutyReportBo bo, HttpServletResponse response) {
        List<DutyReportVo> list = iDutyReportService.queryList(bo);
        ExcelUtil.exportExcel(list, "值班报告信息", DutyReportVo.class, response);
    }

    /**
     * 获取值班报告信息详细信息
     */
    @ApiOperation("获取值班报告信息详细信息")
    @GetMapping("/{id}")
    public AjaxResult<DutyReportVo> getInfo(@NotNull(message = "主键不能为空")
                                            @PathVariable("id") String id) {
        return AjaxResult.success(iDutyReportService.queryById(id));
    }

    /**
     * 新增值班报告信息
     */
    @ApiOperation("新增值班报告信息")
    @RepeatSubmit()
    @PostMapping()
    @Security
    public AjaxResult<Void> add(@Validated(AddGroup.class) @RequestBody DutyReportBo bo) {
        LoginUser cacheLoginUser = UserUtil.getCacheLoginUser();
        if (cacheLoginUser != null) {
            bo.setCreateBy(cacheLoginUser.getUsername());
            bo.setCreateByName(cacheLoginUser.getUser().getNickName());
        }
        return toAjax(iDutyReportService.insertByBo(bo) ? 1 : 0);
    }

    @ApiOperation("交班")
    @RepeatSubmit()
    @PostMapping("/passwork")
    @Security
    public AjaxResult<Void> passwork(@RequestBody DutyReportBo bo) {
        return toAjax(iDutyReportService.passwork(bo) ? 1 : 0);
    }

    @ApiOperation("接班")
    @RepeatSubmit()
    @PostMapping("/receivework")
    @Security
    public AjaxResult<Void> receivework(@RequestBody DutyReportRecordVo bo) {
        if (StrUtil.isBlank(bo.getId())) {
            return AjaxResult.error();
        }
        return toAjax(iDutyReportService.receivework(bo.getId()) ? 1 : 0);
    }

    /**
     * 修改值班报告信息
     */
    @ApiOperation("修改值班报告信息")
    @RepeatSubmit()
    @PutMapping()
    @Security
    public AjaxResult<Void> edit(@Validated(EditGroup.class) @RequestBody DutyReportBo bo) {
        return toAjax(iDutyReportService.updateByBo(bo) ? 1 : 0);
    }

    /**
     * 删除值班报告信息
     */
    @ApiOperation("删除值班报告信息")
    @Log(title = "值班报告信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult<Void> remove(@NotEmpty(message = "主键不能为空")
                                   @PathVariable String[] ids) {
        return toAjax(iDutyReportService.deleteWithValidByIds(Arrays.asList(ids), true) ? 1 : 0);
    }
}
