package com.ruoyi.web.controller.zhdd;

import cn.afterturn.easypoi.entity.vo.NormalExcelConstants;
import cn.afterturn.easypoi.excel.entity.ExportParams;
import cn.afterturn.easypoi.excel.entity.enmus.ExcelType;
import cn.afterturn.easypoi.view.PoiBaseView;
import cn.hutool.core.collection.CollUtil;
import com.ruoyi.common.annotation.Security;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.utils.UserUtil;
import com.ruoyi.zhdd.domain.bo.DutyReportRecordBo;
import com.ruoyi.zhdd.domain.vo.DutyReportRecordVo;
import com.ruoyi.zhdd.service.IDutyReportRecordService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.ui.ModelMap;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Set;

/**
 * 值班报告信息Controller
 *
 * @author xintong
 * @date 2021-10-11
 */
@Validated
@Api(value = "值班报告日志信息控制器", tags = {"值班报告日志信息管理"})
@RequiredArgsConstructor(onConstructor_ = @Autowired)
@RestController
@RequestMapping("/zhdd/dutyReportRecord")
public class DutyReportRecordController extends BaseController {

    private final IDutyReportRecordService iDutyReportRecordService;

    @ApiOperation("查询值班报告日志信息列表")
    @GetMapping("/list")
    @Security
    public TableDataInfo<DutyReportRecordVo> list(@Validated(QueryGroup.class) DutyReportRecordBo bo) {
        // 根据当前用户的角色
        LoginUser cacheLoginUser = UserUtil.getCacheLoginUser();
        // 查询角色如果包含admin的，直接查询全部
        Set<String> userRole = cacheLoginUser.getUserRole();
        boolean admin = CollUtil.containsAny(userRole, CollUtil.newHashSet("admin"));
        if (!admin) {
            bo.setCreateBy(cacheLoginUser.getUsername());
            bo.setReceiveUser(cacheLoginUser.getUsername());
        }
        return iDutyReportRecordService.queryPageList(bo);
    }

    /**
     * 导出值班报告信息列表
     */
    @ApiOperation("导出值班报告信息列表")
    @GetMapping("/export")
    @Security
    public void export(@Validated DutyReportRecordBo bo, HttpServletResponse response, HttpServletRequest request, ModelMap modelMap) {
        // 根据当前用户的角色
        LoginUser cacheLoginUser = UserUtil.getCacheLoginUser();
        // 查询角色如果包含admin的，直接查询全部
        Set<String> userRole = cacheLoginUser.getUserRole();
        boolean admin = CollUtil.containsAny(userRole, CollUtil.newHashSet("admin"));
        if (!admin) {
            bo.setCreateBy(cacheLoginUser.getUsername());
            bo.setReceiveUser(cacheLoginUser.getUsername());
        }
        List<DutyReportRecordVo> list = iDutyReportRecordService.queryList(bo);
        ExportParams params = new ExportParams("交接日志", "交接日志", ExcelType.XSSF);
        modelMap.put(NormalExcelConstants.DATA_LIST, list);
        modelMap.put(NormalExcelConstants.CLASS, DutyReportRecordVo.class);
        modelMap.put(NormalExcelConstants.PARAMS, params);
        modelMap.put(NormalExcelConstants.FILE_NAME, "交接日志");
        PoiBaseView.render(modelMap, request, response, NormalExcelConstants.EASYPOI_EXCEL_VIEW);
    }
}
