package com.ruoyi.web.controller.zhdd;

import cn.hutool.core.convert.Convert;
import cn.hutool.core.util.StrUtil;
import cn.hutool.json.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Security;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.zhdd.domain.Plan;
import com.ruoyi.zhdd.domain.PlanFile;
import com.ruoyi.zhdd.domain.bo.IncidentBo;
import com.ruoyi.zhdd.domain.bo.PlanBo;
import com.ruoyi.zhdd.domain.bo.PlanFileBo;
import com.ruoyi.zhdd.domain.vo.PlanFileVo;
import com.ruoyi.zhdd.domain.vo.PlanVo;
import com.ruoyi.zhdd.service.IIncidentService;
import com.ruoyi.zhdd.service.IPlanFileService;
import com.ruoyi.zhdd.service.IPlanService;
import com.ruoyi.zhdd.service.IPlanTaskService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 预案管理Controller
 *
 * @author xitong
 * @date 2021-09-28
 */
@Validated
@Api(value = "预案管理控制器", tags = {"预案管理管理"})
@RequiredArgsConstructor(onConstructor_ = @Autowired)
@RestController
@RequestMapping("/zhdd/plan")
public class PlanController extends BaseController {

    private final IPlanService iPlanService;
    private final IPlanFileService planFileService;
    private final IPlanTaskService planTaskService;
    private final IIncidentService incidentService;

    /**
     * 查询预案管理列表
     */
    @ApiOperation("查询预案管理列表")
    @GetMapping("/list")
    public TableDataInfo<PlanVo> list(@Validated(QueryGroup.class) PlanBo bo) {
        return iPlanService.queryPageList(bo);
    }

    /**
     * 获取预案管理详细信息
     */
    @ApiOperation("获取预案管理详细信息")
    @GetMapping("/{id}")
    public AjaxResult<PlanVo> getInfo(@NotNull(message = "主键不能为空")
                                      @PathVariable("id") String id) {
        return AjaxResult.success(iPlanService.queryById(id));
    }

    /**
     * 新增预案管理
     */
    @ApiOperation("新增预案管理")
    @Log(title = "预案管理", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public AjaxResult<Void> add(@Validated(AddGroup.class) @RequestBody PlanBo bo) {
        return toAjax(iPlanService.insertByBo(bo) ? 1 : 0);
    }

    /**
     * 修改预案管理
     */
    @ApiOperation("修改预案管理")
    @Log(title = "预案管理", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public AjaxResult<Void> edit(@Validated(EditGroup.class) @RequestBody PlanBo bo) {
        return toAjax(iPlanService.updateByBo(bo) ? 1 : 0);
    }

    /**
     * 删除预案管理
     */
    @ApiOperation("删除预案管理")
    @Log(title = "预案管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult<Void> remove(@NotEmpty(message = "主键不能为空")
                                   @PathVariable String[] ids) {
        return toAjax(iPlanService.deleteWithValidByIds(Arrays.asList(ids), true) ? 1 : 0);
    }

    @ApiOperation("新增预案文件")
//    @Log(title = "新增预案文件", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping("/file")
    public AjaxResult<Void> addFile(@RequestBody PlanFileBo planFileBo) {
        return toAjax(planFileService.insertByBo(planFileBo) ? 1 : 0);
    }

    /**
     * 根据类型和来源查询预案
     *
     * @return
     */
    @RepeatSubmit()
    @GetMapping("/queryDetail")
    public AjaxResult queryPlan(@RequestParam Integer type, @RequestParam String planDept) {
        Map<String, Object> map = new HashMap<>(2);
        List<PlanVo> voOne = iPlanService.listVo(Wrappers.<Plan>lambdaQuery().eq(Plan::getType, type).eq(Plan::getCreateDept, planDept));
        List<PlanFileVo> planFileVos = new ArrayList<>();
        if (voOne != null && voOne.size() > 0) {
            map.put("baseTask", planTaskService.queryPlanTaskByPlanId(voOne.get(0).getId()));
            // 查询预案附件
            planFileVos = planFileService.listVo(Wrappers.<PlanFile>lambdaQuery().eq(PlanFile::getPlanId, voOne.get(0).getId()));
        } else {
            map.put("baseTask", null);
        }
        map.put("planFile", planFileVos);
        return AjaxResult.success(map);
    }

    /**
     * 保存事件等级等信息并生成处置方案
     *
     * @param jsonObject
     * @return
     */
    @RepeatSubmit()
    @PostMapping("/saveAndCreate")
    @Security
    public AjaxResult savePlanAndCreate(@RequestBody JSONObject jsonObject) {
        String id = jsonObject.getStr("id");
        Integer type = jsonObject.getInt("type");
        Integer level = jsonObject.getInt("level");
        String planDept = jsonObject.getStr("planDept");
        if (StrUtil.hasBlank(id, Convert.toStr(type), Convert.toStr(level), planDept)) {
            return AjaxResult.error("缺失必要参数！");
        }
        IncidentBo bo = new IncidentBo();
        bo.setId(id);
        bo.setType(type);
        bo.setLevel(level);
        bo.setPlanDept(planDept);
        incidentService.savePlanAndCreate(bo);
        return AjaxResult.success();
    }
}
