package com.ruoyi.web.controller.zhdd;

import cn.afterturn.easypoi.entity.vo.NormalExcelConstants;
import cn.afterturn.easypoi.excel.ExcelImportUtil;
import cn.afterturn.easypoi.excel.entity.ExportParams;
import cn.afterturn.easypoi.excel.entity.ImportParams;
import cn.afterturn.easypoi.excel.entity.enmus.ExcelType;
import cn.afterturn.easypoi.view.PoiBaseView;
import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.convert.Convert;
import cn.hutool.core.util.IdcardUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.service.ISysDictTypeService;
import com.ruoyi.zhdd.domain.Resource;
import com.ruoyi.zhdd.domain.ResourceDetail;
import com.ruoyi.zhdd.domain.bo.ResourceDetailBo;
import com.ruoyi.zhdd.domain.vo.ResourceCarDetailExport;
import com.ruoyi.zhdd.domain.vo.ResourceCarDetailVo;
import com.ruoyi.zhdd.domain.vo.ResourceDetailExport;
import com.ruoyi.zhdd.domain.vo.ResourceDetailVo;
import com.ruoyi.zhdd.domain.vo.ResourceTeamDetailExport;
import com.ruoyi.zhdd.domain.vo.ResourceTeamDetailVo;
import com.ruoyi.zhdd.domain.vo.ResourceVo;
import com.ruoyi.zhdd.service.IResourceDetailService;
import com.ruoyi.zhdd.service.IResourceService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.ui.ModelMap;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.io.IOException;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 应急资源明细Controller
 *
 * @author xintong
 * @date 2021-10-27
 */
@Validated
@Api(value = "应急资源明细控制器", tags = {"应急资源明细管理"})
@RequiredArgsConstructor(onConstructor_ = @Autowired)
@RestController
@RequestMapping("/zhdd/resourceDetail")
public class ResourceDetailController extends BaseController {

    private final IResourceDetailService iResourceDetailService;
    private final IResourceService resourceService;
    private final ISysDictTypeService dictTypeService;

    /**
     * 查询应急资源明细列表
     */
    @ApiOperation("查询应急资源明细列表")
    @GetMapping("/list")
    public TableDataInfo<ResourceDetailVo> list(@Validated(QueryGroup.class) ResourceDetailBo bo) {
        return iResourceDetailService.queryPageList(bo);
    }

    /**
     * 导出应急资源明细列表
     */
    @ApiOperation("导出应急资源明细列表")
    @Log(title = "应急资源明细", businessType = BusinessType.EXPORT)
    @GetMapping("/export/{ids}")
    public void export(@PathVariable String[] ids, HttpServletResponse response, HttpServletRequest request, ModelMap modelMap) {
        // 物资明细
        List<ResourceDetailVo> detailList = iResourceDetailService.listVo(Wrappers.<ResourceDetail>lambdaQuery()
            .in(ResourceDetail::getResourceId, Arrays.asList(ids)));

        // 查询仓库名称
        List<Resource> resourceList = resourceService.list(Wrappers.<Resource>lambdaQuery().in(Resource::getId, Arrays.asList(ids)));
        Map<String, Resource> resourceCollect = resourceList.stream().collect(Collectors.toMap(Resource::getId, a -> a));

        // 行业主管单位
        List<SysDictData> zhdd_admin_org = dictTypeService.selectDictDataByType("zhdd_admin_org");
        Map<String, String> adminOrgCollect = zhdd_admin_org.stream().collect(Collectors.toMap(SysDictData::getDictValue, SysDictData::getDictLabel));

        // 根据仓库的类型判断走哪一种导出bean
        if (resourceList.size() > 0) {
            Integer resourceType = resourceList.get(0).getResourceType();
            if (resourceType == 1) {
                // 应急仓库
                List<ResourceDetailExport> exportList = new ArrayList<>();
                Map<String, List<ResourceDetailVo>> detailCollect = detailList.stream().collect(Collectors.groupingBy(ResourceDetailVo::getResourceId));
                for (Map.Entry<String, List<ResourceDetailVo>> stringListEntry : detailCollect.entrySet()) {
                    ResourceDetailExport bean = new ResourceDetailExport();
                    Resource resource = resourceCollect.get(stringListEntry.getKey());
                    bean.setAdminOrgName(StrUtil.isNotBlank(resource.getAdminOrgName()) ? adminOrgCollect.get(resource.getAdminOrgName()) : "");
                    bean.setResourceName(resource.getName());
                    bean.setManageUnit(resource.getManageUnit());
                    bean.setContactName(resource.getContactName());
                    bean.setContactPhone(resource.getContactPhone());
                    bean.setAddress(resource.getAddress());
                    bean.setDetail(stringListEntry.getValue());
                    exportList.add(bean);
                }
                ExportParams params = new ExportParams("仓库物资明细", "仓库物资", ExcelType.XSSF);
                params.setFreezeCol(6);
                modelMap.put(NormalExcelConstants.DATA_LIST, exportList);
                modelMap.put(NormalExcelConstants.CLASS, ResourceDetailExport.class);
                modelMap.put(NormalExcelConstants.PARAMS, params);
                modelMap.put(NormalExcelConstants.FILE_NAME, "仓库物资明细");
                PoiBaseView.render(modelMap, request, response, NormalExcelConstants.EASYPOI_EXCEL_VIEW);
            } else if (resourceType == 2) {
                // 应急队伍
                List<ResourceTeamDetailExport> exportList = new ArrayList<>();
                List<ResourceTeamDetailVo> teamDetailList = new ArrayList<>();
                for (ResourceDetailVo resourceDetailVo : detailList) {
                    ResourceTeamDetailVo resourceTeamDetailVo = new ResourceTeamDetailVo();
                    BeanUtil.copyProperties(resourceDetailVo, resourceTeamDetailVo);
                    teamDetailList.add(resourceTeamDetailVo);
                }
                Map<String, List<ResourceTeamDetailVo>> detailCollect = teamDetailList.stream().collect(Collectors.groupingBy(ResourceTeamDetailVo::getResourceId));
                for (Map.Entry<String, List<ResourceTeamDetailVo>> stringListEntry : detailCollect.entrySet()) {
                    ResourceTeamDetailExport bean = new ResourceTeamDetailExport();
                    Resource resource = resourceCollect.get(stringListEntry.getKey());
                    bean.setAdminOrgName(StrUtil.isNotBlank(resource.getAdminOrgName()) ? adminOrgCollect.get(resource.getAdminOrgName()) : "");
                    bean.setResourceName(resource.getName());
                    bean.setManageUnit(resource.getManageUnit());
                    bean.setContactName(resource.getContactName());
                    bean.setContactPhone(resource.getContactPhone());
                    bean.setAddress(resource.getAddress());
                    bean.setDetail(stringListEntry.getValue());
                    exportList.add(bean);
                }
                ExportParams params = new ExportParams("队伍物资明细", "队伍物资", ExcelType.XSSF);
                params.setFreezeCol(6);
                modelMap.put(NormalExcelConstants.DATA_LIST, exportList);
                modelMap.put(NormalExcelConstants.CLASS, ResourceTeamDetailExport.class);
                modelMap.put(NormalExcelConstants.PARAMS, params);
                modelMap.put(NormalExcelConstants.FILE_NAME, "队伍物资明细");
                PoiBaseView.render(modelMap, request, response, NormalExcelConstants.EASYPOI_EXCEL_VIEW);
            } else if (resourceType == 3) {
                // 应急车船
                List<ResourceCarDetailExport> exportList = new ArrayList<>();
                List<ResourceCarDetailVo> carDetailList = new ArrayList<>();
                for (ResourceDetailVo resourceDetailVo : detailList) {
                    ResourceCarDetailVo resourceCarDetailVo = new ResourceCarDetailVo();
                    BeanUtil.copyProperties(resourceDetailVo, resourceCarDetailVo);
                    carDetailList.add(resourceCarDetailVo);
                }
                Map<String, List<ResourceCarDetailVo>> detailCollect = carDetailList.stream().collect(Collectors.groupingBy(ResourceCarDetailVo::getResourceId));
                for (Map.Entry<String, List<ResourceCarDetailVo>> stringListEntry : detailCollect.entrySet()) {
                    ResourceCarDetailExport bean = new ResourceCarDetailExport();
                    Resource resource = resourceCollect.get(stringListEntry.getKey());
                    bean.setAdminOrgName(StrUtil.isNotBlank(resource.getAdminOrgName()) ? adminOrgCollect.get(resource.getAdminOrgName()) : "");
                    bean.setManageUnit(resource.getManageUnit());
                    bean.setContactName(resource.getContactName());
                    bean.setContactPhone(resource.getContactPhone());
                    bean.setAddress(resource.getAddress());
                    bean.setDetail(stringListEntry.getValue());
                    exportList.add(bean);
                }
                ExportParams params = new ExportParams("车船物资明细", "车船物资", ExcelType.XSSF);
                params.setFreezeCol(5);
                modelMap.put(NormalExcelConstants.DATA_LIST, exportList);
                modelMap.put(NormalExcelConstants.CLASS, ResourceCarDetailExport.class);
                modelMap.put(NormalExcelConstants.PARAMS, params);
                modelMap.put(NormalExcelConstants.FILE_NAME, "车船物资明细");
                PoiBaseView.render(modelMap, request, response, NormalExcelConstants.EASYPOI_EXCEL_VIEW);
            }
        }

    }

    @ApiOperation("导入队伍人员数据")
    @Log(title = "导入队伍人员数据", businessType = BusinessType.IMPORT)
    @PostMapping("/importUser")
    public AjaxResult<?> importExcel(HttpServletRequest request) {
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        String resourceId = request.getParameter("resourceId");
        if (StrUtil.isBlank(resourceId)) {
            return null;
        }
        // 查询应急资源是否为应急队伍的类型
        ResourceVo resourceVo = resourceService.getVoById(resourceId);
        if (resourceVo == null || resourceVo.getResourceType() != 2) {
            return null;
        }
        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
        for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
            MultipartFile file = entity.getValue();// 获取上传文件对象
            ImportParams params = new ImportParams();
            params.setTitleRows(1);
            params.setHeadRows(1);
            try {
                List<ResourceDetail> list = ExcelImportUtil.importExcel(file.getInputStream(), ResourceDetail.class, params);
                List<ResourceDetail> newList = new ArrayList<>();
                for (ResourceDetail resourceDetail : list) {
                    if (StrUtil.isBlank(resourceDetail.getName())) {
                        continue;
                    }
                    resourceDetail.setResourceId(resourceId);
                    resourceDetail.setResourceType(resourceVo.getResourceType());
                    resourceDetail.setNum(new BigDecimal(1));
                    resourceDetail.setUnit("人");
                    // 计算性别、年龄(1 : 男 ， 0 : 女)、出生年月
                    if (StrUtil.isNotBlank(resourceDetail.getIdcard()) && IdcardUtil.isValidCard(resourceDetail.getIdcard())) {
                        int age = IdcardUtil.getAgeByIdCard(resourceDetail.getIdcard());
                        int gender = IdcardUtil.getGenderByIdCard(resourceDetail.getIdcard());
                        String birth = IdcardUtil.getBirth(resourceDetail.getIdcard());
                        resourceDetail.setSex(gender == 1 ? "男" : gender == 0 ? "女" : "未知");
                        resourceDetail.setAge(Convert.toStr(age));
                        resourceDetail.setBirth(birth.substring(0, 4) + "-" + birth.substring(4, 6) + "-" + birth.substring(6));
                    }
                    newList.add(resourceDetail);
                }
                iResourceDetailService.saveAll(newList);
                return AjaxResult.success("导入成功" + newList.size() + "条");
            } catch (Exception e) {
                return AjaxResult.error("文件导入失败:" + e.getMessage());
            } finally {
                try {
                    file.getInputStream().close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
        return AjaxResult.error("文件导入失败！");

    }

    /**
     * 获取应急资源明细详细信息
     */
    @ApiOperation("获取应急资源明细详细信息")
    @GetMapping("/{id}")
    public AjaxResult<ResourceDetailVo> getInfo(@NotNull(message = "主键不能为空")
                                                @PathVariable("id") String id) {
        return AjaxResult.success(iResourceDetailService.queryById(id));
    }

    /**
     * 新增应急资源明细
     */
    @ApiOperation("新增应急资源明细")
    @Log(title = "应急资源明细", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public AjaxResult<Void> add(@Validated(AddGroup.class) @RequestBody ResourceDetailBo bo) {
        return toAjax(iResourceDetailService.insertByBo(bo) ? 1 : 0);
    }

    /**
     * 修改应急资源明细
     */
    @ApiOperation("修改应急资源明细")
    @Log(title = "应急资源明细", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public AjaxResult<Void> edit(@Validated(EditGroup.class) @RequestBody ResourceDetailBo bo) {
        return toAjax(iResourceDetailService.updateByBo(bo) ? 1 : 0);
    }

    /**
     * 删除应急资源明细
     */
    @ApiOperation("删除应急资源明细")
    @Log(title = "应急资源明细", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult<Void> remove(@NotEmpty(message = "主键不能为空")
                                   @PathVariable String[] ids) {
        return toAjax(iResourceDetailService.deleteWithValidByIds(Arrays.asList(ids), true) ? 1 : 0);
    }

    @ApiOperation("通过物资检索应急仓库")
    @GetMapping("/searchWarehouseByGoods")
    public AjaxResult<List<ResourceVo>> searchWarehouseByGoods(ResourceDetailBo bo) {
        List<ResourceVo> list = iResourceDetailService.searchWarehouseByGoods(bo);
        return AjaxResult.success(list);
    }
}
