package com.ruoyi.framework.config;

import cn.hutool.core.util.StrUtil;
import com.ruoyi.framework.config.properties.TokenProperties;
import feign.Contract;
import feign.Feign;
import feign.Logger;
import feign.Request;
import feign.RequestInterceptor;
import feign.Retryer;
import lombok.extern.slf4j.Slf4j;
import okhttp3.ConnectionPool;
import okhttp3.OkHttpClient;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.AutoConfigureBefore;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.cloud.openfeign.EnableFeignClients;
import org.springframework.cloud.openfeign.FeignAutoConfiguration;
import org.springframework.cloud.openfeign.support.SpringMvcContract;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;
import java.util.concurrent.TimeUnit;

/**
 * openfeign配置类
 *
 * @author Lion Li
 */
@EnableFeignClients("${feign.package}")
@Configuration
@ConditionalOnClass(Feign.class)
@AutoConfigureBefore(FeignAutoConfiguration.class)
@Slf4j
public class FeignConfig {

    @Autowired
    private TokenProperties tokenProperties;

    @Bean
    public RequestInterceptor requestInterceptor() {
        return requestTemplate -> {
            ServletRequestAttributes attributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
            if (null != attributes) {
                HttpServletRequest request = attributes.getRequest();
                log.info("Feign request: {}", request.getRequestURI());
                // 将token信息放入header中
                String token = request.getHeader(tokenProperties.getHeader());
                String user = request.getHeader("user");
                if (token == null || "".equals(token)) {
                    token = request.getParameter("token");
                }
                if (StrUtil.isBlank(user)) {
                    user = request.getParameter("user");
                }
                requestTemplate.header(tokenProperties.getHeader(), token);
                requestTemplate.header("user", user);
            } else {
                // 传递固定的用户信息
                requestTemplate.header("user", "%7B%22principal%22%3A%7B%22userName%22%3A%22sqadmin1%22%2C%22orgId%22%3A%22255d0081f46f48f290109c373a73cfba%22%2C%22orgName%22%3A%22%E5%AE%BF%E8%BF%81%E5%B8%82%E4%BA%A4%E9%80%9A%E8%BF%90%E8%BE%93%E7%BB%BC%E5%90%88%E8%A1%8C%E6%94%BF%E6%89%A7%E6%B3%95%E6%94%AF%E9%98%9F%22%2C%22permissions%22%3A%5B%5D%7D%2C%22user_name%22%3A%22sqadmin1%22%2C%22scope%22%3A%5B%22all%22%2C%22PRODUCT_API%22%2C%22MEMBER_READ%22%5D%2C%22id%22%3A%22a4349c10bf454b3f83047734b5d742ff%22%2C%22exp%22%3A1657739822%2C%22jti%22%3A%22c4f70336-36e3-467f-b438-41664bf310c9%22%2C%22user_group_id%22%3A2%2C%22client_id%22%3A%22tpbd%22%2C%22username%22%3A%22sqadmin1%22%7D");
            }
        };
    }

    @Bean
    public OkHttpClient okHttpClient() {
        return new OkHttpClient.Builder()
            .readTimeout(60, TimeUnit.SECONDS)
            .connectTimeout(60, TimeUnit.SECONDS)
            .writeTimeout(120, TimeUnit.SECONDS)
            .connectionPool(new ConnectionPool())
            .build();
    }

    @Bean
    public Contract feignContract() {
        return new SpringMvcContract();
    }

    @Bean
    public Logger.Level feignLoggerLevel() {
        return Logger.Level.BASIC;
    }

    @Bean
    public Request.Options feignRequestOptions() {
        return new Request.Options(10, TimeUnit.SECONDS, 60, TimeUnit.SECONDS, true);
    }

    @Bean
    public Retryer feignRetry() {
        return new Retryer.Default();
    }

//	/**
//	 * 自定义异常解码器
//	 * 用于自定义返回体异常熔断
//	 */
//	@Bean
//	public ErrorDecoder errorDecoder() {
//		return new CustomErrorDecoder();
//	}
//
//
//	/**
//	 * 自定义返回体解码器
//	 */
//	@Slf4j
//	public static class CustomErrorDecoder implements ErrorDecoder {
//
//		@Override
//		public Exception decode(String methodKey, Response response) {
//			Exception exception = null;
//			try {
//				// 获取原始的返回内容
//				String json = JsonUtils.toJsonString(response.body().asReader(StandardCharsets.UTF_8));
//				exception = new RuntimeException(json);
//				// 将返回内容反序列化为Result，这里应根据自身项目作修改
//				AjaxResult result = JsonUtils.parseObject(json, AjaxResult.class);
//				// 业务异常抛出简单的 RuntimeException，保留原来错误信息
//				if (result.getCode() != 200) {
//					exception = new RuntimeException(result.getMsg());
//				}
//			} catch (IOException e) {
//				log.error(e.getMessage(), e);
//			}
//			return exception;
//		}
//	}

}
