package com.ruoyi.zhdd.domain.bo;

import com.ruoyi.common.core.domain.BaseEntity;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.util.List;

/**
 * 应急资源业务对象 b_resource
 *
 * @author xintong
 * @date 2021-10-27
 */

@Data
@EqualsAndHashCode(callSuper = true)
@ApiModel("应急资源业务对象")
public class ResourceBo extends BaseEntity {

    /**
     * $column.columnComment
     */
    @ApiModelProperty(value = "$column.columnComment")
    @NotBlank(message = "id不能为空", groups = {EditGroup.class})
    private String id;

    /**
     * 资源类型。1-仓库。2-队伍.3-车辆
     */
    @ApiModelProperty(value = "资源类型。1-仓库。2-队伍.3-车辆")
    @NotNull(message = "resourceType不能为空", groups = {AddGroup.class})
    private Integer resourceType;

    @ApiModelProperty(value = "位置类型")
    @NotBlank(message = "locationType不能为空", groups = {AddGroup.class})
    private String locationType;

    /**
     * 名称
     */
    @ApiModelProperty(value = "名称")
//    @NotBlank(message = "name不能为空", groups = {AddGroup.class, EditGroup.class})
    private String name;

    /**
     * 地址
     */
    @ApiModelProperty(value = "地址")
    private String address;

    /**
     * 经度
     */
    @ApiModelProperty(value = "经度")
    private String longitude;

    /**
     * 纬度
     */
    @ApiModelProperty(value = "纬度")
    private String latitude;

    /**
     * 管理单位
     */
    @ApiModelProperty(value = "管理单位")
    private String manageUnit;

    private String manageUnitId;

    private String deptId;

    private List<String> deptIds;

    /**
     * 人数
     */
    @ApiModelProperty(value = "人数")
    private Integer num;

    /**
     * 联系人
     */
    @ApiModelProperty(value = "联系人")
    @NotBlank(message = "contactName不能为空", groups = {AddGroup.class, EditGroup.class})
    private String contactName;

    /**
     * 联系电话
     */
    @ApiModelProperty(value = "联系电话")
    @NotBlank(message = "contactPhone不能为空", groups = {AddGroup.class, EditGroup.class})
    private String contactPhone;

    /**
     * $column.columnComment
     */
    @ApiModelProperty(value = "$column.columnComment")
    private String delFlag;


    /**
     * 分页大小
     */
    @ApiModelProperty("分页大小")
    private Integer pageSize;

    /**
     * 当前页数
     */
    @ApiModelProperty("当前页数")
    private Integer pageNum;

    /**
     * 排序列
     */
    @ApiModelProperty("排序列")
    private String orderByColumn;

    /**
     * 排序的方向desc或者asc
     */
    @ApiModelProperty(value = "排序的方向", example = "asc,desc")
    private String isAsc;

    private List<ResourceDetailBo> resourceDetailList;

    /**
     * 应急仓库中应急物资名称
     */
    private String goodsName;

    private List<Object> resourceIds;
    private List<Object> resourceNotIds;

    // 等于1的情况下，查询存在物资的仓库
    private String notNullFlag;

    private String adminOrgName;
}
