package com.ruoyi.zhdd.feign;

import cn.hutool.json.JSONObject;
import com.ruoyi.zhdd.domain.AppInfo;
import com.ruoyi.zhdd.domain.GatewayDeptDetail;
import com.ruoyi.zhdd.domain.GatewayDeptList;
import com.ruoyi.zhdd.domain.GatewayDeptPage;
import com.ruoyi.zhdd.domain.GatewayUserDetail;
import com.ruoyi.zhdd.domain.GatewayUserPage;
import com.ruoyi.zhdd.feign.fallback.FeignUserManageFallback;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * @Description: 四维用户接口
 * @Author: huangcheng
 * @Date: 2022/1/12
 * @Version V1.0
 */
@FeignClient(value = "tpbd-usermanager", fallback = FeignUserManageFallback.class)
public interface FeignUserManageService {

    /**
     * 用户详情
     *
     * @param userId
     */
    @GetMapping("/user/detail")
    GatewayUserDetail userDetail(@RequestParam(value = "userId") String userId);

    @GetMapping("/user/pageList")
    GatewayUserPage userPage(@RequestParam(value = "name", required = false) String name, @RequestParam(value = "pageNum") Integer pageNum, @RequestParam(value = "pageSize") Integer pageSize);

    /**
     * 部门详情
     *
     * @param id
     * @return
     */
    @GetMapping("/orgdept/detail")
    GatewayDeptDetail deptDetail(@RequestParam(value = "id") String id);

    /**
     * 部门所有数据
     *
     * @return
     */
    @GetMapping("/orgdept/list")
    GatewayDeptList deptList();

    /**
     * 部门分页数据
     *
     * @param pageNum
     * @param pageSize
     * @param name
     * @return
     */
    @GetMapping("/orgdept/pageList")
    GatewayDeptPage deptPageList(@RequestParam(value = "pageNum") Integer pageNum, @RequestParam(value = "pageSize") Integer pageSize, @RequestParam(value = "name") String name);

    /**
     * 第三方进行更新应用操作
     *
     * @return
     */
    @PostMapping("/app/updateApp/systemInfo")
    JSONObject updateSystemInfo(@RequestBody AppInfo appInfo);

    /**
     * 更新系统数据量
     *
     * @param appId
     * @param dataCount
     * @return
     */
    @PostMapping("/app-update/updateDataCount")
    JSONObject updateDataCount(@RequestParam(value = "appId") String appId, @RequestParam(value = "dataCount") Integer dataCount);

    /**
     * 更新数据用户数
     *
     * @param appId
     * @param userCount
     * @return
     */
    @PostMapping("/app-update/updateUserCount")
    JSONObject updateUserCount(@RequestParam(value = "appId") String appId, @RequestParam(value = "userCount") Integer userCount);
}
