package com.ruoyi.zhdd.service.impl;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.mybatisplus.core.ServicePlusImpl;
import com.ruoyi.common.core.page.PagePlus;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.PageUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.zhdd.domain.DutyEmp;
import com.ruoyi.zhdd.domain.bo.DutyEmpBo;
import com.ruoyi.zhdd.domain.bo.DutyEmpSaveBo;
import com.ruoyi.zhdd.domain.vo.DutyEmpVo;
import com.ruoyi.zhdd.mapper.DutyEmpMapper;
import com.ruoyi.zhdd.service.IDutyEmpService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 值班排班信息Service业务层处理
 *
 * @author xintong
 * @date 2021-10-11
 */
@Service
public class DutyEmpServiceImpl extends ServicePlusImpl<DutyEmpMapper, DutyEmp, DutyEmpVo> implements IDutyEmpService {

    @Override
    public DutyEmpVo queryById(String id) {
        return getVoById(id);
    }

    @Override
    public TableDataInfo<DutyEmpVo> queryPageList(DutyEmpBo bo) {
        PagePlus<DutyEmp, DutyEmpVo> result = pageVo(PageUtils.buildPagePlus(), buildQueryWrapper(bo));
        return PageUtils.buildDataInfo(result);
    }

    @Override
    public List<DutyEmpVo> queryList(DutyEmpBo bo) {
        return listVo(buildQueryWrapper(bo));
    }

    private LambdaQueryWrapper<DutyEmp> buildQueryWrapper(DutyEmpBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<DutyEmp> lqw = Wrappers.lambdaQuery();
        lqw.eq(bo.getPeriod() != null, DutyEmp::getPeriod, bo.getPeriod());
        lqw.like(StringUtils.isNotBlank(bo.getEmpName()), DutyEmp::getEmpName, bo.getEmpName());
        return lqw;
    }

    @Override
    @Transactional
    public Boolean insertByBo(DutyEmpSaveBo bo) {
        // 校验是否存在重叠时间段
        List<String> periods = bo.getDutyDetailList().stream().map(DutyEmpSaveBo.DutyDetail::getPeriodTime).collect(Collectors.toList());
        for (int i = 0; i < periods.size(); i++) {
            int startTime = DateUtil.timeToSecond(periods.get(i).split("~")[0]);
            int endTime = DateUtil.timeToSecond(periods.get(i).split("~")[1]);
            for (int j = i + 1; j < periods.size(); j++) {
                // 循环比较
                int compareStartTime = DateUtil.timeToSecond(periods.get(j).split("~")[0]);
                int compareEndTime = DateUtil.timeToSecond(periods.get(j).split("~")[1]);
                if ((startTime > compareStartTime && startTime < compareEndTime) ||
                    (endTime > compareStartTime && endTime < compareEndTime) ||
                    (startTime <= compareStartTime && endTime >= compareEndTime)) {
                    throw new ServiceException(periods.get(i) + "存在重叠时间段，请检查！");
                }
            }
        }
        List<DutyEmp> list = new ArrayList<>();
        for (DutyEmpSaveBo.DutyDetail dutyDetail : bo.getDutyDetailList()) {
            DutyEmp dutyEmp = new DutyEmp();
            dutyEmp.setPeriod(bo.getPeriod());
            dutyEmp.setPeriodTime(dutyDetail.getPeriodTime());
            dutyEmp.setEmpJson(dutyDetail.getEmpJson());
            List<SysUser> users = JSONUtil.toList(StrUtil.blankToDefault(dutyDetail.getEmpJson(), "[]"), SysUser.class);
            String userNames = users.stream().map(SysUser::getNickName).collect(Collectors.joining(","));
            dutyEmp.setEmpName(userNames);
            list.add(dutyEmp);
        }
        // 先删除之前的星期数据
        this.remove(Wrappers.<DutyEmp>lambdaQuery().eq(DutyEmp::getPeriod, bo.getPeriod()));
        return saveBatch(list);
    }

    @Override
    public Boolean deleteWithValidByIds(Collection<String> ids, Boolean isValid) {
        if (isValid) {
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return removeByIds(ids);
    }

}
