package com.ruoyi.zhdd.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.convert.Convert;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpStatus;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.core.mybatisplus.core.ServicePlusImpl;
import com.ruoyi.common.core.page.PagePlus;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.PageUtils;
import com.ruoyi.common.utils.UserUtil;
import com.ruoyi.zhdd.domain.DutyReportRecord;
import com.ruoyi.zhdd.domain.bo.DutyReportRecordBo;
import com.ruoyi.zhdd.domain.vo.DutyReportRecordVo;
import com.ruoyi.zhdd.mapper.DutyReportRecordMapper;
import com.ruoyi.zhdd.service.IDutyReportRecordService;
import org.springframework.stereotype.Service;

import java.sql.Timestamp;
import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 值班报告信息Service业务层处理
 *
 * @author xintong
 * @date 2021-10-11
 */
@Service
public class DutyReportRecordServiceImpl extends ServicePlusImpl<DutyReportRecordMapper, DutyReportRecord, DutyReportRecordVo> implements IDutyReportRecordService {

    @Override
    public DutyReportRecordVo queryById(String id) {
        return getVoById(id);
    }

    @Override
    public TableDataInfo<DutyReportRecordVo> queryPageList(DutyReportRecordBo bo) {
        PagePlus<DutyReportRecord, DutyReportRecordVo> result = pageVo(PageUtils.buildPagePlus(), buildQueryWrapper(bo));
        TableDataInfo<DutyReportRecordVo> rspData = new TableDataInfo<>();
        rspData.setCode(HttpStatus.HTTP_OK);
        rspData.setMsg("查询成功");
        rspData.setRows(result.getRecordsVo());
        rspData.setTotal(result.getTotal());
        rspData.setPageNum(result.getCurrent());
        rspData.setPageSize(result.getSize());
        LoginUser cacheLoginUser = UserUtil.getCacheLoginUser();
        rspData.setCurrentUser(cacheLoginUser.getUsername());
        return rspData;
    }

    @Override
    public List<DutyReportRecordVo> queryList(DutyReportRecordBo bo) {
        return listVo(buildQueryWrapper(bo));
    }

    private LambdaQueryWrapper<DutyReportRecord> buildQueryWrapper(DutyReportRecordBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<DutyReportRecord> lqw = Wrappers.lambdaQuery();
        lqw.and(StrUtil.isNotBlank(bo.getCreateBy()) && StrUtil.isNotBlank(bo.getReceiveUser()), a -> a.eq(DutyReportRecord::getCreateBy, bo.getCreateBy()).or().eq(DutyReportRecord::getReceiveUser, bo.getReceiveUser()));
        if (params.get("beginTime") != null && params.get("endTime") != null) {
            lqw.between(DutyReportRecord::getPassDateTime, Timestamp.valueOf(Convert.toStr(params.get("beginTime")) + " 00:00:00"), Timestamp.valueOf(Convert.toStr(params.get("endTime")) + " 23:59:59"));
        }
        if (params.get("receiveBeginTime") != null && params.get("receiveEndTime") != null) {
            lqw.between(DutyReportRecord::getReceiveDateTime, Timestamp.valueOf(Convert.toStr(params.get("receiveBeginTime")) + " 00:00:00"), Timestamp.valueOf(Convert.toStr(params.get("receiveEndTime")) + " 23:59:59"));
        }
        if (params.get("createByName") != null) {
            lqw.like(DutyReportRecord::getCreateByName, params.get("createByName"));
        }
        if (params.get("receiveUserName") != null) {
            lqw.like(DutyReportRecord::getReceiveUserName, params.get("receiveUserName"));
        }
        lqw.orderByDesc(DutyReportRecord::getCreateTime);
        return lqw;
    }

    @Override
    public Boolean insertByBo(DutyReportRecordBo bo) {
        DutyReportRecord add = BeanUtil.toBean(bo, DutyReportRecord.class);
        return save(add);
    }

    @Override
    public Boolean updateByBo(DutyReportRecordBo bo) {
        DutyReportRecord update = BeanUtil.toBean(bo, DutyReportRecord.class);
        return updateById(update);
    }

    @Override
    public Boolean deleteWithValidByIds(Collection<String> ids, Boolean isValid) {
        if (isValid) {
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return removeByIds(ids);
    }

}
