package com.ruoyi.zhdd.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ruoyi.common.core.mybatisplus.core.ServicePlusImpl;
import com.ruoyi.common.core.page.PagePlus;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.PageUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.zhdd.domain.IncidentProcess;
import com.ruoyi.zhdd.domain.IncidentTask;
import com.ruoyi.zhdd.domain.bo.BacklogMessageUpdateBo;
import com.ruoyi.zhdd.domain.bo.IncidentProcessBo;
import com.ruoyi.zhdd.domain.vo.IncidentProcessVo;
import com.ruoyi.zhdd.domain.vo.IncidentTaskVo;
import com.ruoyi.zhdd.feign.FeignBacklogInfoService;
import com.ruoyi.zhdd.mapper.IncidentProcessMapper;
import com.ruoyi.zhdd.service.IIncidentProcessService;
import com.ruoyi.zhdd.service.IIncidentTaskService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 事件处置流程Service业务层处理
 *
 * @author xitong
 * @date 2021-09-28
 */
@Service
@Slf4j
public class IncidentProcessServiceImpl extends ServicePlusImpl<IncidentProcessMapper, IncidentProcess, IncidentProcessVo> implements IIncidentProcessService {

    @Autowired
    private FeignBacklogInfoService feignBacklogInfoService;
    @Autowired
    private IIncidentTaskService incidentTaskService;
    @Value("${third.incidentDetailUrl}")
    private String incidentDetailUrl;
    @Value("${third.resourceUrl}")
    private String resourceUrl;

    @Override
    public IncidentProcessVo queryById(String id) {
        return getVoById(id);
    }

    @Override
    public TableDataInfo<IncidentProcessVo> queryPageList(IncidentProcessBo bo) {
        PagePlus<IncidentProcess, IncidentProcessVo> result = pageVo(PageUtils.buildPagePlus(), buildQueryWrapper(bo));
        return PageUtils.buildDataInfo(result);
    }

    @Override
    public List<IncidentProcessVo> queryList(IncidentProcessBo bo) {
        return listVo(buildQueryWrapper(bo));
    }

    private LambdaQueryWrapper<IncidentProcess> buildQueryWrapper(IncidentProcessBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<IncidentProcess> lqw = Wrappers.lambdaQuery();
        lqw.eq(bo.getIncidentId() != null, IncidentProcess::getIncidentId, bo.getIncidentId());
        lqw.eq(StringUtils.isNotBlank(bo.getDes()), IncidentProcess::getDes, bo.getDes());
        return lqw;
    }

    @Override
    public String insertByBo(IncidentProcessBo bo) {
        IncidentProcess add = BeanUtil.toBean(bo, IncidentProcess.class);
        validEntityBeforeSave(add);
        add.setIncidentStatus(3);
        save(add);
        return add.getId();
    }

    @Override
    public Boolean updateByBo(IncidentProcessBo bo) {
        IncidentProcess update = BeanUtil.toBean(bo, IncidentProcess.class);
        validEntityBeforeSave(update);
        return updateById(update);
    }

    /**
     * 保存前的数据校验
     *
     * @param entity 实体类数据
     */
    private void validEntityBeforeSave(IncidentProcess entity) {
        //TODO 做一些数据校验,如唯一约束
    }

    @Override
    public Boolean deleteWithValidByIds(Collection<String> ids, Boolean isValid) {
        if (isValid) {
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return removeByIds(ids);
    }

    /**
     * @param id 方案id
     * @return
     */
    @Override
    @Transactional
    public boolean backLogFinish(String id) {
        // 通过方案id查询处置过程的id值
        List<IncidentProcess> taskList = this.list(Wrappers.<IncidentProcess>lambdaQuery().eq(IncidentProcess::getTaskId, id).in(IncidentProcess::getStatus, 2, 3));
        if (taskList != null && taskList.size() > 0) {
            IncidentProcess incidentProcess = taskList.get(0);
            String uuid = incidentProcess.getId();
            // 办结
            List<BacklogMessageUpdateBo> list = new ArrayList<>();
            BacklogMessageUpdateBo bo = new BacklogMessageUpdateBo();
            bo.setUuId(uuid);
            // 查询事件的id
            IncidentTaskVo incidentTaskVo = incidentTaskService.queryById(id);
            if (incidentTaskVo == null) {
                return false;
            }
            String sendFlag = incidentTaskVo.getSendFlag();
            String url = "";
            if ("2".equals(sendFlag)) {
                url = incidentDetailUrl.replace("#incidentId", incidentTaskVo.getIncidentId());
            } else if ("3".equals(sendFlag)) {
                url = resourceUrl.replace("#taskId", "");
            }
            bo.setUrl(url);
            list.add(bo);
            Object o = feignBacklogInfoService.backlogMessageUpdate(list);
            log.info("消息待办办结返回结果:{}", o);
            // 更新办结状态
            IncidentTask incidentTask = new IncidentTask();
            incidentTask.setId(id);
            incidentTask.setBackLogFlag("1");
            incidentTaskService.updateById(incidentTask);
            // 更新日志里面的待办改为已办
            incidentProcess.setDes(incidentProcess.getDes().replace("【待办】", "【已办】"));
            this.updateById(incidentProcess);
        }
        return true;
    }
}
